@@ -8,6 +8,12 @@
 
 #define trace_xfs_agfl_reset(a,b,c,d)		((void) 0)
 #define trace_xfs_agfl_free_defer(a,b,c,d,e)	((void) 0)
+#define trace_xfs_alloc_cur_check(a,b,c,d,e,f)	((void) 0)
+#define trace_xfs_alloc_cur(a)			((void) 0)
+#define trace_xfs_alloc_cur_left(a)		((void) 0)
+#define trace_xfs_alloc_cur_lookup(a)		((void) 0)
+#define trace_xfs_alloc_cur_lookup_done(a)	((void) 0)
+#define trace_xfs_alloc_cur_right(a)		((void) 0)
 #define trace_xfs_alloc_exact_done(a)		((void) 0)
 #define trace_xfs_alloc_exact_notfound(a)	((void) 0)
 #define trace_xfs_alloc_exact_error(a)		((void) 0)
@@ -40,6 +46,10 @@
 #define trace_xfs_btree_corrupt(a,b)		((void) 0)
 #define trace_xfs_btree_updkeys(a,b,c)		((void) 0)
 #define trace_xfs_btree_overlapped_query_range(a,b,c)	((void) 0)
+#define trace_xfs_btree_commit_afakeroot(a)	((void) 0)
+#define trace_xfs_btree_commit_ifakeroot(a)	((void) 0)
+#define trace_xfs_btree_bload_level_geometry(a,b,c,d,e,f,g) ((void) 0)
+#define trace_xfs_btree_bload_block(a,b,c,d,e,f) ((void) 0)
 
 #define trace_xfs_free_extent(a,b,c,d,e,f,g)	((void) 0)
 #define trace_xfs_agf(a,b,c,d)			((void) 0)
@@ -53,6 +63,8 @@
 #define trace_xfs_iext_insert(a,b,c,d)		((void) 0)
 #define trace_xfs_iext_remove(a,b,c,d)		((void) 0)
 
+#define trace_xfs_defer_relog_intent(a,b)	((void) 0)
+
 #define trace_xfs_dir2_grow_inode(a,b)		((void) 0)
 #define trace_xfs_dir2_shrink_inode(a,b)	((void) 0)
 
@@ -153,9 +165,9 @@
 #define trace_xfs_bmap_pre_update(a,b,c,d)	((void) 0)
 #define trace_xfs_bmap_post_update(a,b,c,d)	((void) 0)
 #define trace_xfs_bunmap(a,b,c,d,e)		((void) 0)
+#define trace_xfs_read_extent(a,b,c,d)		((void) 0)
 
 /* set c = c to avoid unused var warnings */
-#define trace_xfs_read_extent(a,b,c,d)	((c) = (c))
 #define trace_xfs_write_extent(a,b,c,d)	((c) = (c))
 #define trace_xfs_perag_get(a,b,c,d)	((c) = (c))
 #define trace_xfs_perag_get_tag(a,b,c,d) ((c) = (c))
