@@ -493,7 +493,7 @@ _("Scrub aborted after phase %d."),
 			break;
 
 		/* Too many errors? */
-		if (xfs_scrub_excessive_errors(ctx)) {
+		if (scrub_excessive_errors(ctx)) {
 			ret = ECANCELED;
 			break;
 		}
@@ -603,6 +603,12 @@ main(
 	setlocale(LC_ALL, "");
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
+	if (unicrash_load()) {
+		fprintf(stderr,
+	_("%s: couldn't initialize Unicode library.\n"),
+				progname);
+		goto out;
+	}
 
 	pthread_mutex_init(&ctx.lock, NULL);
 	ctx.mode = SCRUB_MODE_REPAIR;
@@ -761,7 +767,7 @@ main(
 	 * We don't want every thread yelling that into the output, so check
 	 * if we hit the threshold and tell the user *once*.
 	 */
-	if (xfs_scrub_excessive_errors(&ctx))
+	if (scrub_excessive_errors(&ctx))
 		str_info(&ctx, ctx.mntpoint, _("Too many errors; aborting."));
 
 	if (debug_tweak_on("XFS_SCRUB_FORCE_ERROR"))
@@ -788,6 +794,7 @@ out:
 	phase_end(&all_pi, 0);
 	if (progress_fp)
 		fclose(progress_fp);
+	unicrash_unload();
 
 	/*
 	 * If we're being run as a service, the return code must fit the LSB
